# ECAL Calibration

This project is meant to calibrate at analysis level the electron energy measurement 
made by the LHCb ECAL calorimeter.

## Environment

The code assumes that the following variables are available:

```
ANADIR: Path to a directory where outputs can be written to
```

